////////////////////////////////////////////////////////////////////////////
// BT848                                                                  //
//------------------------------------------------------------------------//
// Defines all BT848 registers & gives                                    //
// access to them.                                                        //
//                                                                        //
//------------------------------------------------------------------------//
// V 0.0 - 27.02.97/Kl                                                    //
//                                                                        //
// revisions:                                                             //
// V 1.0 - 12.03.97/U.T. RELEASE VERSION                                  //
// V 1.1 - 28.05.98/Kl                                                    //
//                                                                        //
// (c) PHYTEC Messtechnik GmbH Mainz                                      //
////////////////////////////////////////////////////////////////////////////


#ifndef BT848_H

#define BT848_H

#include "standards.h"
#include "PCI.H"

#define EVEN   0
#define ODD    1
#define LINE_SPACE_ERROR 999 ;

// Define all local BT 848 register addresses

const WORD DSTATUS      = 0x000;
const WORD IFORM        = 0x004;
const WORD TDEC         = 0x008;
const WORD E_CROP       = 0x00C;
const WORD O_CROP       = 0x08C;
const WORD E_VDELAY_LO  = 0x010;
const WORD O_VDELAY_LO  = 0x090;
const WORD E_VACTIVE_LO = 0x014;
const WORD O_VACTIVE_LO = 0x094;
const WORD E_DELAY_LO   = 0x018;
const WORD O_DELAY_LO   = 0x098;
const WORD E_HACTIVE_LO = 0x01C;
const WORD O_HACTIVE_LO = 0x09C;
const WORD E_HSCALE_HI  = 0x020;
const WORD O_HSCALE_HI  = 0x0A0;
const WORD E_HSCALE_LO  = 0x024;
const WORD O_HSCALE_LO  = 0x0A4;
const WORD BRIGHT       = 0x028;
const WORD E_CONTROL    = 0x02C;
const WORD O_CONTROL    = 0x0AC;
const WORD CONTRAST_LO  = 0x030;
const WORD SAT_U_LO     = 0x034;
const WORD SAT_V_LO     = 0x038;
const WORD HUE          = 0x03C;
const WORD E_SCLOOP     = 0x040;
const WORD O_SCLOOP     = 0x0C0;
//const WORD OFORM        = 0x006;       // ???????
const WORD OFORM        = 0x048;

const WORD E_VSCALE_HI  = 0x04C;
const WORD O_VSCALE_HI  = 0x0CC;
const WORD E_VSCALE_LO  = 0x050;
const WORD O_VSCALE_LO  = 0x0D0;
const WORD ADELAY       = 0x060;
const WORD BDELAY       = 0x064;
const WORD ADC          = 0x068;
const WORD E_VTC        = 0x06C;
const WORD O_VTC        = 0x0EC;
const WORD SRESET       = 0x07C;
const WORD COLOR_FMT    = 0x0D4;
const WORD COLOR_CTL    = 0x0D8;
const WORD CAP_CTL      = 0x0DC;
const WORD VBI_PACK_SIZE= 0x0E0;
const WORD VBI_PACK_DEL = 0x0E4;
const WORD FCAP         = 0x0E8;
const WORD INT_STAT     = 0x100;
const WORD INT_MASK     = 0x104;
const WORD RISC_COUNT   = 0x120;
const WORD RISC_STRT_ADD= 0x114;
const WORD GPIO_DMA_CTL = 0x10C;
const WORD GPIO_OUT_EN  = 0x118;
const WORD GPIO_REG_INP = 0x11C;
const WORD GPIO_DATA    = 0x200;
const WORD I2C_DATA     = 0x110;
const WORD WHITE_CRUSH_UP   = 0x044;
const WORD WHITE_CRUSH_DOWN = 0x078;

/****************************************************************************
        RISC CONSTANTS
****************************************************************************/
const long WRITE         =0x10000000;
const long WRITE123      =0x90000000;
const long WRITE1S23     =0xB0000000;
const long WRITEC        =0x50000000;
const long SKIP          =0x20000000;
const long SKIP123       =0xA0000000;
const long JUMP          =0x70000000;
const long SYNC          =0x80000000;
const long RESYNC        =0x80008000;

const long FM1_STAT      =0x00000006;
const long FM3_STAT      =0x0000000E;
const long SOL_STAT      =0x00000002;
const long EOL4_STAT     =0x00000001;
const long EOL3_STAT     =0x0000000D;
const long EOL2_STAT     =0x00000009;
const long EOL1_STAT     =0x00000005;
const long VRE_STAT      =0x00000004;
const long VRO_STAT      =0x0000000C;
const long PXV_STAT      =0x00000000;
                        
const long SOL           =0x08000000;
const long EOL           =0x04000000;

const long BE_0000       =0x00000000;
const long BE_0001       =0x00001000;
const long BE_0010       =0x00002000;
const long BE_0011       =0x00003000;
const long BE_0100       =0x00004000;
const long BE_0101       =0x00005000;
const long BE_0110       =0x00006000;
const long BE_0111       =0x00007000;
const long BE_1000       =0x00008000;
const long BE_1001       =0x00009000;
const long BE_1010       =0x0000A000;
const long BE_1011       =0x0000B000;
const long BE_1100       =0x0000C000;
const long BE_1101       =0x0000D000;
const long BE_1110       =0x0000E000;
const long BE_1111       =0x0000F000;


//////////////////////////////////////
// Color Format Register
//////////////////////////////////////

const char RGB32         =0 ;
const char RGB24         =1 ;
const char RGB16         =2 ;
const char RGB15         =3 ;
const char YUY2          =4 ;
const char BtYUV         =5 ;
const char Y8            =6 ;
const char RGB8          =7 ;

/////////////////////////////////////////////////////
// CLASS DEFINITION: BT848                         //
/////////////////////////////////////////////////////

class BT848
{
   private:


   struct RISC_MEM_STRUCT
   {
      unsigned long lStart;
      unsigned long lSize;
   } *pRiscMemDes ;             // Pointer to Risc Memory
                                // description array

  public:
      PCI *PCI_IO;

      BT848(void);                                              
      ~BT848(void);

      unsigned short Max_Device_Number() ;

      short Read_Local_Byte(short nDevice_Number, short                         
                nLRegister_Number,unsigned char *nContent) ;

      short Write_Local_Byte(short nDevice_Number, short                        
                nLRegister_Number, unsigned char nContent) ;

      short Read_Local_Word(short nDevice_Number, short                         
                nLRegister_Number, unsigned short *nContent) ;

      short Write_Local_Word(short nDevice_Number, short                        
                nLRegister_Number, unsigned short nContent) ;

      short Read_Local_DWord(short nDevice_Number, short                        
                nLRegister_Number, unsigned long *nContent) ;

      short Write_Local_DWord(short nDevice_Number, short                       
                nLRegister_Number, unsigned long lContent) ;

      void HaltRisc(short nDevNo);

      void RunRisc(short nDevNo);

      short AllocateRiscMemory(short nDevice_Number, long lRisc_Size) ;
      short FreeRiscMemory(short nDevice_Number) ;
      short CreateRiscProgramm(short nDevice_Number,
                                 unsigned short nE_PPL, unsigned short nE_Lines,
                                 unsigned short nE_hSkip, unsigned short nE_vSkip,
                                 unsigned short nE_Col, unsigned long lE_Mem,
                                 unsigned short nO_PPL, unsigned short nO_Lines,
                                 unsigned short nO_hSkip, unsigned short nO_vSkip,
                                 unsigned short nO_Col, unsigned long lO_Mem,
                                 unsigned short nInterlaced, unsigned short nSingleShot);

      BOOL Check848(WORD nDevNo);
      DWORD GetProductCode(WORD nDevNo);
};



#endif
