/***********************************************************************/
/* Device-Driver for pciGrabber-4, DOS Mode                            */
/*                                                                     */
/* *NOTE: DOS4GW DPMI-Interface required                               */
/*        Compiled with WATCOM C++ Compiler                            */
/*                                                                     */
/*                                                                     */
/* V0.0 -    03.97/Tr                                                  */
/* Revisions:                                                          */
/* V1.0 - 13.11.97/U.T. RELEASE VERSION                                */
/* V1.1 - 28.05.98/Kl   Set_Image: Korrektur bentigter RISC-Speicher- */
/*                                 platz.                              */
/*                                                                     */
/*                                                                     */
/*                                                                     */
/*                                                                     */
/* (c) 1997,98 PHYTEC Messtechnik GmbH Mainz                           */
/***********************************************************************/

#ifndef pciGrabber4
#define pciGrabber4

#include "bt848.h"
#include "i2c.h"

/*---------------------------------------------------------------------*/
/* Constants                                                           */
/*---------------------------------------------------------------------*/

#define NTSC_M      0                             // Constant names to     
#define PAL_BDGHI   1                             // define Video-Systems
#define SECAM       2                             //
#define PAL_M       3                             //
#define PAL_N       4                             //
#define AUTO        5                             // Auto selection mode

// error codes
#define SUCCESSFUL              0                 // Error Codes
#define UNKNOWN_DEVICE_NUMBER   1
#define BAD_REGISTER_NUMBER     2
#define INITIALIZATION_FAILED   3
#define GRABBER_NOT_FOUND       4
#define INVALID_PARAMETER       5
#define NOT_SUPPORTED           6
#define OLD_VERSION             7
#define NO_PHYTEC_GRABBER_FOUND 8

#define UNKNOWN_ERROR           99

// SVideo defines
#define MINIDIN                 0x10
#define COMBI                   0x11
#define NO_SIGNAL               0x12

// i2c protocol
#define NOACK                   9
#define INVALID_ADDRESS         10
#define WRITE_FAILED            11

// Configuration types
#define GRABBER_TYPE        0x01
#define MAX_CHANNEL         0x02


// Grabber product codes
#define VD_007              0x00
#define VD_009              0x01
#define VD_009_X1           0x02
#define EPC_032             0x03
#define EPC_032_X1          0x04
#define EPC_032_X2          0x05
#define EPC_032_X1_X2       0x06
#define VD_009_RS6          0x07
#define VD_009_X1_RS6       0x08
#define VD_011              0x09
#define VD_011_RS6          0x0A

// interrupt
#define OFF                 0x00
#define VSYNC               0x02

typedef struct _DESCRIPTOR
{
        short           dwProductCode ;
        char            *sProductString;
        short           MaxChannel;
} DESCRIPTOR ;


class PCI_GRABBER4 
{
   private:

   I2C   *I2CInterface;
   unsigned short error_status;                // holds the current error code 
   
   public:
   BT848 *Video;                                 // The Videoprocessor Interface 
   PCI_GRABBER4();                                // Class constructor 
   ~PCI_GRABBER4();                               // Class destructor 

   void Stop_Grabber(unsigned short nDevNo) ;  
   void Start_Grabber(unsigned short nDevNo) ; 
   short Data_Present(unsigned short nDevNo) ; 
   unsigned short Max_Device_Number() ;         
   unsigned short Get_Error(void) ;                                               
   void Initialize(unsigned short nDevNo);                                        

   short Read_Local_DWord(unsigned short nDevice_Number, unsigned short nRegister_Number, unsigned long *lContent) ;
   short Write_Local_DWord(unsigned short nDevice_Number, unsigned short nRegister_Number, unsigned long lContent) ;
  
   void Set_Image(unsigned short nDevNo, unsigned short nOhpos, unsigned short nOvpos, unsigned short nOhsize,
                  unsigned short nOvsize, unsigned short nOppl, unsigned short nOlines, unsigned short nOColformat,
                  unsigned char *pOImgBuf, 
                  unsigned short nEhpos, unsigned short nEvpos, unsigned short nEhsize, unsigned short nEvsize,
                  unsigned short nEppl, unsigned short nElines, unsigned short nEColformat,
                  unsigned char *pEImgBuf,
                  unsigned short nColSystem, unsigned short nInterlaced, unsigned short nSingleShot) ;
   void Set_Image_Pos(unsigned short nDevNo,
                       unsigned short nOhpos, unsigned short nOvpos, unsigned short nOppl, 
                       unsigned short nEhpos, unsigned short nEvpos, unsigned short nEppl,
                       unsigned short nColSystem) ;
   void Set_Color_System(unsigned short nDevNo, unsigned short nColSys);       
   void Set_Brightness(unsigned short nDevNo,short nBright);                     
   void Set_Contrast(unsigned short nDevNo, unsigned short nContr);             
   void Set_Saturation(unsigned short nDevNo, unsigned short nSat_U, unsigned short nSat_V);
   void Set_Hue(unsigned short nDevNo, short nHue);                              
   void Set_S_Video(unsigned short nDevNo);
   unsigned char Set_S_VideoEx(unsigned short nDevNo, unsigned char mode);
   void Set_Composite(unsigned short nDevNo) ;
   void Set_BW(unsigned short nDevNo, unsigned short nOn);
   void Set_LDec(unsigned short nDevNo, unsigned short nOn, unsigned short nHFilt) ;
   void Set_Channel(unsigned short nDevNo, unsigned short nChannel);
   void Set_ChannelEx(WORD nDevNo, WORD nChannel);
   void Set_Interlace(unsigned short nDevNo, unsigned short nInterlace) ;
   void Set_AGC(unsigned short nDevNo, unsigned short nCAGC,
                 unsigned short nAGC, unsigned short nCrush) ;
   void Set_ColorBars(unsigned short nDevNo, unsigned short nColorBars) ;
   void Set_CKill(unsigned short nDevNo, unsigned short nCKill) ;
   void Set_GPIO_Direction(unsigned short nDevNo, unsigned short nDirection) ;
   void Set_GPIO_Data(unsigned short nDevNo, unsigned short nData) ;
   void TemporalDect(unsigned short nDevNo, unsigned short nDecField,
                          unsigned short nFldAlign, unsigned short nDecRat) ;
   void LumaControl(unsigned short nDevNo, unsigned short nRange, unsigned short nCore) ;
    
   short Get_Brightness(unsigned short nDevNo);
   unsigned short Get_Contrast(unsigned short nDevNo);
   unsigned short Get_Sat_U(unsigned short nDevNo);
   unsigned short Get_Sat_V(unsigned short nDevNo);
   short Get_HUE(unsigned short nDevNo);
   short Get_Hue(unsigned short nDevNo);
   void Get_Image_Size(unsigned short nDevNo, unsigned short nField, short col_system, short *hpos, short *vpos, short *hsize, short *vsize, short *ppl, short *lines) ;
   short Get_Signal_Status(unsigned short nDevNo) ;
   short Get_Video_Status(unsigned short nDevNo) ;
   unsigned short Get_GPIO_Data(unsigned short nDevNo) ;
   void Get_IRQ_Status(unsigned short nDevNo, unsigned long *lIRQ_Reg, unsigned long *lRISC_Addr);
   void I2C_Set_BR_Mode(WORD nDevNo, BYTE bMode);
   BYTE I2C_ReadByte(WORD nDevNo, BYTE bChipAddress, BYTE bSubAddress, BYTE *bByteRead);
   BYTE I2C_WriteByte(WORD nDevNo, BYTE bChipAddress, BYTE bSubAddress, BYTE bData);
   BYTE I2C_ReadEEProm(WORD nDevNo, BYTE bSubAddress, BYTE *bByteRead);
   BYTE I2C_WriteEEProm(WORD nDevNo, BYTE bSubAddress, BYTE bData);
   short Read_GrabberInfo(WORD nDevNo, WORD wInfoType);
   void Set_Ext_IO(unsigned short nDevNo, unsigned char bData);
   unsigned char Read_Ext_IO(WORD nDevNo);
   unsigned char Get_CaptureCounter(WORD nDevNo);
   void Reset_CaptureCounter(WORD nDevNo);
   short Read_OrderCode(WORD nDevNo, unsigned char *sCodeString, DWORD dwSizeOfString);
   unsigned short Set_Interrupt(WORD nDevNo, DWORD nInterrupt);
   unsigned short Reset_Interrupt(WORD nDevNo);
   BYTE I2C_WriteEEPromSV(WORD nDevNo, BYTE bSubAddress, BYTE bData);


// DEBUG please remove this for the release version
   BYTE I2C_WriteBytePHYTEC(WORD nDevNo, BYTE bSubAddress, BYTE bData);
   BYTE I2C_ReadBytePHYTEC(WORD nDevNo, BYTE bSubAddress, BYTE *bByteRead);





private:
   void Set_Image_Size(unsigned short nDevNo, unsigned short nField, short hpos, short vpos, short hsize, short vsize, short ppl, short lines, short col_system) ;
} ;


#endif
